@@ -15,6 +15,7 @@
 #include <QStringList>
 
 #include <memory>
+#include <sys/types.h> // dev_t among other definitions
 
 class KMountPointPrivate;
 
@@ -29,7 +30,8 @@ class KMountPointPrivate;
 class KIOCORE_EXPORT KMountPoint : public QSharedData
 {
 public:
-    typedef QExplicitlySharedDataPointer<KMountPoint> Ptr;
+    using Ptr = QExplicitlySharedDataPointer<KMountPoint>;
+
     /**
      * List of mount points.
      */
@@ -58,12 +60,22 @@ public:
 public:
     /**
      * Flags that specify which additional details should be fetched for each mountpoint.
-     * BasicInfoNeeded: only the basic details: mountedFrom, mountPoint, mountType.
-     * NeedMountOptions: also fetch the options used when mounting, see mountOptions.
-     * NeedRealDeviceName: also fetch the device name (with symlinks resolved), see realDeviceName.
      * @see DetailsNeededFlags
      */
-    enum DetailsNeededFlag { BasicInfoNeeded = 0, NeedMountOptions = 1, NeedRealDeviceName = 2 };
+    enum DetailsNeededFlag {
+        /**
+         * Only the basic details: mountedFrom, mountPoint, mountType.
+         */
+        BasicInfoNeeded = 0,
+        /**
+         * Also fetch the options used when mounting, see KMountPoint::mountOptions().
+         */
+        NeedMountOptions = 1,
+        /**
+         * Also fetch the device name (with symlinks resolved), see KMountPoint::realDeviceName().
+         */
+        NeedRealDeviceName = 2,
+    };
     /**
      * Stores a combination of #DetailsNeededFlag values.
      */
@@ -77,11 +89,12 @@ public:
     static List possibleMountPoints(DetailsNeededFlags infoNeeded = BasicInfoNeeded);
 
     /**
-     * This function gives a list of all currently used mountpoints. (mtab)
+     * Returns a list of all current mountpoints.
+     *
      * @param infoNeeded Flags that specify which additional information
      * should be fetched.
      *
-     * @note this method will return an empty list on Android
+     * @note This method will return an empty list on @c Android
      */
     static List currentMountPoints(DetailsNeededFlags infoNeeded = BasicInfoNeeded);
 
@@ -91,6 +104,22 @@ public:
      */
     QString mountedFrom() const;
 
+    /**
+     * Returns @c true if this mount point represents a network filesystem (e.g.\ NFS,
+     * CIFS, etc.), otherwise returns @c false.
+     *
+     * @since 5.86
+     */
+    bool isOnNetwork() const;
+
+    /**
+     * Returns the device ID (dev_t, major, minor) of this mount point. This
+     * ID is unique per device (including network mounts).
+     *
+     * @since 5.86
+     */
+    dev_t deviceId() const;
+
     /**
      * Canonical name of the device where the filesystem got mounted from.
      * (Or empty, if not a device)
@@ -99,7 +128,8 @@ public:
     QString realDeviceName() const;
 
     /**
-     * Path where the filesystem is mounted or can be mounted.
+     * Path where the filesystem is mounted (if you used @ref currentMountPoints()),
+     * or can be mounted (if you used @ref possibleMountPoints()).
      */
     QString mountPoint() const;
 
@@ -110,13 +140,13 @@ public:
 
     /**
      * Options used to mount the filesystem.
-     * Only available when the NeedMountOptions flag was set.
+     * Only available if the @ref NeedMountOptions flag was set.
      */
     QStringList mountOptions() const;
 
     /**
-     * Checks if the filesystem that is probably slow (network mounts).
-     * @return true if the filesystem is probably slow
+     * Returns @c true if the filesystem is "probably" slow, e.g.\ a network mount,
+     * @c false otherwise.
      */
     bool probablySlow() const;
 
@@ -127,6 +157,7 @@ public:
         SupportsSymlinks,
         CaseInsensitive,
     };
+
     /**
      * Checks the capabilities of the filesystem.
      * @param flag the flag to check
@@ -142,7 +173,7 @@ public:
      * @li SupportsSymlinks: returns true if the filesystems supports symlinks
      * (e.g. msdos filesystems return false)
      * @li CaseInsensitive: returns true if the filesystem treats
-     * "foo" and "FOO" as being the same file (true for msdos systems)
+     * "foo" and "FOO" as being the same file (true for msdos filesystems)
      *
      */
     bool testFileSystemFlag(FileSystemFlag flag) const;
@@ -156,11 +187,16 @@ private:
     /**
      * Constructor
      */
-    KMountPoint();
+    KIOCORE_NO_EXPORT KMountPoint();
+
+    friend KIOCORE_EXPORT QDebug operator<<(QDebug debug, const Ptr &mp);
+
     friend KMountPointPrivate;
     std::unique_ptr<KMountPointPrivate> d;
 };
 
+KIOCORE_EXPORT QDebug operator<<(QDebug debug, const KMountPoint::Ptr &mp);
+
 Q_DECLARE_OPERATORS_FOR_FLAGS(KMountPoint::DetailsNeededFlags)
 
 #endif // KMOUNTPOINT_H
