@@ -12,6 +12,8 @@
 #include <QProgressDialog>
 #include <QTimer>
 
+#include <memory>
+
 class KBuildSycocaProgressDialogPrivate;
 /**
  * @class KBuildSycocaProgressDialog kbuildsycocaprogressdialog.h <KBuildSycocaProgressDialog>
@@ -30,11 +32,11 @@ public:
     static void rebuildKSycoca(QWidget *parent);
 
 private:
-    KBuildSycocaProgressDialog(QWidget *parent, const QString &caption, const QString &text);
-    ~KBuildSycocaProgressDialog();
+    KIOWIDGETS_NO_EXPORT KBuildSycocaProgressDialog(QWidget *parent, const QString &title, const QString &text);
+    KIOWIDGETS_NO_EXPORT ~KBuildSycocaProgressDialog() override;
 
 private:
-    KBuildSycocaProgressDialogPrivate *const d;
+    std::unique_ptr<KBuildSycocaProgressDialogPrivate> const d;
 };
 
 #endif
