@@ -1,37 +1,34 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                       David Faure <faure@kde.org>
-    Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
-    Copyright (C) 2013 Dawit Alemayehu <adawit@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2006 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2013 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_JOBUIDELEGATE_H
 #define KIO_JOBUIDELEGATE_H
 
 #include <KDialogJobUiDelegate>
-#include <kio/jobuidelegateextension.h>
-#include <kio/skipdialog.h>
-#include <kio/renamedialog.h>
+#include <kio/askuseractioninterface.h>
 #include <kio/global.h>
+#include <kio/jobuidelegateextension.h>
+#include <kio/renamedialog.h>
+#include <kio/skipdialog.h>
 
 class KJob;
+class KDirOperator;
+class KIOWidgetJobUiDelegateFactory;
+
 namespace KIO
 {
+class JobUiDelegatePrivate;
+
+class FileUndoManager;
+
 class Job;
 
 /**
@@ -42,28 +39,57 @@ class Job;
 class KIOWIDGETS_EXPORT JobUiDelegate : public KDialogJobUiDelegate, public JobUiDelegateExtension
 {
     Q_OBJECT
+    // Allow the factory to construct. Everyone else needs to go through the factory or derive!
+    friend class ::KIOWidgetJobUiDelegateFactory;
+    // KIO internals don't need to derive either
+    friend class KIO::FileUndoManager;
 
 public:
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 98)
     /**
      * Constructs a new KIO Job UI delegate.
+     * @deprecated Since 5.98, use KIO::createDefaultJobUiDelegate or versioned constructor instead
      */
+    KIOWIDGETS_DEPRECATED_VERSION(5, 98, "use KIO::createDefaultJobUiDelegate or versioned constructor instead")
     JobUiDelegate();
+#endif
 
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 98)
     /**
      * Constructs a new KIO Job UI Delegate.
      * @param flags allows to enable automatic error/warning handling
      * @param window the window associated with this delegate, see setWindow.
-     * @since 5.70
+     * @since 5.70,
+     * @deprecated Since 5.98, use KIO::createDefaultJobUiDelegate or versioned constructor instead
      */
+    KIOWIDGETS_DEPRECATED_VERSION(5, 98, "use KIO::createDefaultJobUiDelegate or versioned constructor instead")
     explicit JobUiDelegate(KJobUiDelegate::Flags flags, QWidget *window);
+#endif
 
+protected:
+    friend class ::KDirOperator;
+
+    enum class Version {
+        V2,
+    };
+
+    /**
+     * Constructs a new KIO Job UI delegate.
+     * @param version does nothing purely here to disambiguate this constructor from the deprecated older constructors.
+     * @param flags allows to enable automatic error/warning handling
+     * @param window the window associated with this delegate, see setWindow.
+     * @param ifaces Interface instances such as OpenWithHandlerInterface to replace the default interfaces
+     * @since 5.98
+     */
+    explicit JobUiDelegate(Version version, KJobUiDelegate::Flags flags = AutoHandlingDisabled, QWidget *window = nullptr, const QList<QObject *> &ifaces = {});
+
+public:
     /**
      * Destroys the KIO Job UI delegate.
      */
-    virtual ~JobUiDelegate();
+    ~JobUiDelegate() override;
 
 public:
-
     /**
      * Associate this job with a window given by @p window.
      * @param window the window to associate to
@@ -87,7 +113,7 @@ public:
      * a result code, as well as the new dest. Much easier to use than the
      * class RenameDialog directly.
      *
-     * @param caption the caption for the dialog box
+     * @param title the title for the dialog box
      * @param src the URL of the file/dir we're trying to copy, as it's part of the text message
      * @param dest the URL of the destination file/dir, i.e. the one that already exists
      * @param options parameters for the dialog (which buttons to show...)
@@ -101,7 +127,7 @@ public:
      * @return the result
      */
     RenameDialog_Result askFileRename(KJob *job,
-                                      const QString &caption,
+                                      const QString &title,
                                       const QUrl &src,
                                       const QUrl &dest,
                                       KIO::RenameDialog_Options options,
@@ -117,9 +143,7 @@ public:
      * @internal
      * See skipdialog.h
      */
-    SkipDialog_Result askSkip(KJob *job,
-                              KIO::SkipDialog_Options options,
-                              const QString &error_text) override;
+    SkipDialog_Result askSkip(KJob *job, KIO::SkipDialog_Options options, const QString &error_text) override;
 
     /**
      * Ask for confirmation before deleting/trashing @p urls.
@@ -133,33 +157,33 @@ public:
      * Note: the window passed to setWindow is used as the parent for the message box.
      * @return true if confirmed
      */
-    bool askDeleteConfirmation(const QList<QUrl> &urls, DeletionType deletionType,
-                               ConfirmationType confirmationType) override;
+    bool askDeleteConfirmation(const QList<QUrl> &urls, DeletionType deletionType, ConfirmationType confirmationType) override;
 
     /**
-    * This function allows for the delegation user prompts from the ioslaves.
-    *
-    * @param type the desired type of message box.
-    * @param text the message shown to the user.
-    * @param caption the caption of the message dialog box.
-    * @param buttonYes the text for the YES button.
-    * @param buttonNo the text for the NO button.
-    * @param iconYes the icon shown on the YES button.
-    * @param iconNo the icon shown on the NO button.
-    * @param dontAskAgainName the name used to store result from 'Do not ask again' checkbox.
-    * @param metaData SSL information used by the SSLMessageBox. Since 5.66 this is also used for privilege operation details.
-    *
-    * @since 4.11
-    *
-    * @internal
-    */
+     * This function allows for the delegation user prompts from the KIO workers.
+     *
+     * @param type the desired type of message box.
+     * @param text the message shown to the user.
+     * @param title the title of the message dialog box.
+     * @param primaryActionText the text for the primary action button.
+     * @param secondaryActionText the text for the secondary action button.
+     * @param primaryActionIconName the icon shown on the primary action button.
+     * @param secondaryActionIconName the icon shown on the secondary action button.
+     * @param dontAskAgainName the name used to store result from 'Do not ask again' checkbox.
+     * @param metaData SSL information used by the SSLMessageBox. Since 5.66 this is also used for privilege operation details.
+     *
+     * @since 4.11
+     *
+     * @internal
+     */
     // KF6 TODO Add a QString parameter for "details" and keep in sync with API in SlaveBase, SlaveInterface, and JobUiDelegateExtension.
-    int requestMessageBox(MessageBoxType type, const QString &text,
-                          const QString &caption,
-                          const QString &buttonYes,
-                          const QString &buttonNo,
-                          const QString &iconYes = QString(),
-                          const QString &iconNo = QString(),
+    int requestMessageBox(MessageBoxType type,
+                          const QString &text,
+                          const QString &title,
+                          const QString &primaryActionText,
+                          const QString &secondaryActionText,
+                          const QString &primaryActionIconName = QString(),
+                          const QString &secondaryActionIconName = QString(),
                           const QString &dontAskAgainName = QString(),
                           const KIO::MetaData &metaData = KIO::MetaData()) override;
 
@@ -173,8 +197,7 @@ public:
     void updateUrlInClipboard(const QUrl &src, const QUrl &dest) override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<JobUiDelegatePrivate> const d;
 };
 }
 
